<!-- markdownlint-disable-next-line first-line-heading -->
<img src="img/saphiera.png" align="right" width="250px"/>

# saphiera

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/a060b69ebb37442ca97cd2ae6e16c837)](https://app.codacy.com?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)
[![codecov](https://codecov.io/github/Pillar-ML/saphiera/graph/badge.svg?token=RoEGmqXs38)](https://codecov.io/github/Pillar-ML/saphiera)
[![All Contributors](https://img.shields.io/github/all-contributors/Pillar-ML/saphiera?color=ee8449&style=flat-square)](#contributors)

Secure Authoritative Python Hiera configuration management.

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
